{% load i18n %}
<div class="jsonsuit editable" data-jsonsuit="{{ name }}">
  <button type="button" class="toggle button" data-raw="{% trans 'Raw' %}" data-suit="{% trans 'Suit' %}">{% trans 'Raw' %}</button>
  {{ textarea }}
  <div class="suit">
    <pre><code class="language-json" data-raw="{{ value }}"></code></pre>
  </div>
</div>
